iOS web app in Python

# Write your full screen iOS web apps in Python using Transcrypt!

The application is cached, so it will also work when the user doesn't have an Internet connection. For a truly native experience, the address bar is hidden and scrolling or zooming are blocked. In the application, you can access the current location of the user.

Use the "Add to Home Screen" option on your iOS device, in combination with a number of special tags, as can be seen in the html code of the example below. The effect is an application that is indeed cached and has native look and feel. Still it can be simply downloaded from any site.

As a bonus your web app will also work in any browser. So finally make that game or commercial app, simply in your favorite language... Welcome to the wonderfull world of Transcrypt app development!

# Add this simple dice example to your homescreen and try it...